<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Zavřít (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Složit</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozbalit</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Odvolat poplach</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% z %Ln minut</numerusform>
            <numerusform>%1% z %Ln minut</numerusform>
            <numerusform>%1% z %Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% z %Ln slov</numerusform>
            <numerusform>%1% z %Ln slov</numerusform>
            <numerusform>%1% z %Ln slov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln slovo</numerusform>
            <numerusform>%Ln slova</numerusform>
            <numerusform>%Ln slov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minuty</numerusform>
            <numerusform>%Ln minut</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Denní postup</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Nejdelší proužek</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Nynější proužek</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nedostupné</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n den</numerusform>
            <numerusform>%n dny</numerusform>
            <numerusform>%n dnů</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% z denního cíle</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Nastavit jazyk</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (pouze pro čtení)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nelze uložit &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Uložit soubor jako</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nelze přepsat &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Přejmenovat soubor</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nelze přejmenovat &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Nahrát soubor znovu?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Nahrát soubor &apos;%1&apos; znovu z disku?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Všechny neuložené změny budou ztraceny.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Uložení v prostém textu zahodí všechno formátování. Zahodit formátování?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Soubor změněn</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Soubor &apos;%1&apos; byl změněn jiným programem.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Chcete soubor nahrát znovu?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Přehlížet</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Soubor smazán</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Soubor %1 byl smazán jiným programem.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Chcete soubor uložit nebo zavřít?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Nahradit:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Nevšímat si velikosti písmen</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Pouze celá slova</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regulární výrazy</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Hledat nahoru</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Hledat dolů</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Nahradit</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Nahradit &amp;vše</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Najít</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Nahradit jeden případ?</numerusform>
            <numerusform>Nahradit %n případy?</numerusform>
            <numerusform>Nahradit %n případů?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Slovní spojení nebylo nenalezeno.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>Plochý XML OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Prostý text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Všechny podporované soubory</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Ověření pravopisu...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nebyly nalezeny žádné návrhy)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Obrázky (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Nástrojový pruh</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Správné psaní</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Vybrat slovník</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Archiv neobsahuje použitelný slovník.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Střet jedné nebo více zkratek. Chcete pokračovat?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Slovník &quot;%1&quot; již existuje. Chcete jej nahradit?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Denní cíl</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minut:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Slov:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Umístit vždy svisle do středu</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Ukazatel vkládání bloku</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Vyhlazená písma</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Zvuky psacího stroje</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Typografické uvozovky:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>dvojité</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>jednoduché</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scény</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Oddělovač</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Ukládání</translation>
    </message>
    <message>
        <source>Automatically save changes</source>
        <translation>Automaticky uložit změny</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Zapamatovat si polohu ukazatele</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Počet slov</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Počet stran</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Počet odstavců</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Počet znaků</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znaků:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Odstavců:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmus pro počítání slov</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Nastavit denní postup pro dnešek znovu na nulu?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Odstranit nynější slovník?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Zapsat značku pro pořadí bytů (BOM) do souborů prostého textu</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Výchozí formát:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Uživatelské rozhraní</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Vždy ukázat posuvník</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Vždy ukázat horní pruh</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Vždy ukázat dolní pruh</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Vynulovat dnešek</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Zapamatovat si historii</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Ukázat proužky</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Nejmenší postup pro proužky:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Zjistit hranice slov</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Vydělit počet znaků šesti</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Počítat každé písmeno za slovo</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmus pro počítání stran</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Pouze ikony</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Pouze text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text vedle ikon</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text pod ikonami</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Poloha textu:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Posunout nahoru</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Posunout dolů</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Přidat oddělovač</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Činnost</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Ověřování pravopisu během psaní</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Nevšímat si slov psaných VELKÝMI PÍSMENY</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Nevšímat si slov s čísly</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Osobní slovník</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Není podporovaným souborem RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neočekávaně dosaženo konce souboru.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+šipka dolů</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Přesunout scény nahoru</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+šipka nahoru</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Přepnout seznam scén</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Ukázat seznam scén (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Skrýt seznam scén (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Přesunout scény dolů</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Změnit velikost seznamu scén</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Spravovat sezení</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;ezení</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nové</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Zdvojit</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Přepnout na</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nové sezení</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Zdvojit sezení</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Přejmenovat sezení</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Smazat vybrané sezení?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Název sezení:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Požadovaný název sezení se již používá.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nové...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Spravovat...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Nastavit znovu na výchozí</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Zkratka:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Nahrazují se uvozovky...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Počkejte, prosím</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Ověření pravopisu</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Pře&amp;hlížet</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Přeh&amp;lížet vše</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Změnit</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Změ&amp;nit</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Ne ve slovníku:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Změnit na:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Ověřuje se pravopis...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Počkejte, prosím</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Pokračovat v kontrole od začátku souboru?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Ověření správného psaní je hotovo.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symboly</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nedávno použité symboly</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Všechny symboly</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skripty</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Žádný obrázek</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Vydlážděno</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Vystředěno</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Roztaženo</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Změněno měřítko</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Přiblíženo</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Poloha:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Kulaté rohy pozadí textu</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Poloměr:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Rozmazané pozadí textu</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Stín pozadí textu</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Svislý posun:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Okno:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Strana:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Odsadit první řádek</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Nad:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Pod:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Upravit vzhled</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Pozadí okna</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Obrázek:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixelů</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Zarovnáno vlevo</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Pozadí textu</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Zarovnáno vpravo</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Špatně napsáno:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Odstupy mezi řádky</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Jednoduchý</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 řádku</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvojitý</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Poměrný</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Odstupy mezi odstavci</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Šířka zarážky:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nový vzhled</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Mrazivé nebe</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Okouzlení</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Něžné blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Stará škola</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Vesmírné sny</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Výzvědné hry</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Mír a klid</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Psací stůl</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Zdvojit</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Zavést</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Smazat vzhled &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Vzhledy (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Zavést vzhled</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Vyvést podobu</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Smazat časomíru?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Slova:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Strany:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Odstavce:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znaky:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Nastavit zpoždění</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Nastavit čas</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Zpoždění:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Čas:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Budík</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Zpráva:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Neběží žádná časomíra</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Časomíry</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Naposledy použitá</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Zrušit časomíry pro úpravy?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Nahrávají se podoby</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Nahrávají se zvuky</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>O programu FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Jednoduchý celoobrazovkový editor textu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorské právo &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Používá ikony z motivu ikon &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Znaky: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Strany: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Odstavce: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Slova: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otevírá se %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Vypsat všechny dokumenty</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Přepnout na další dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Přepnout na předchozí dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Přepnout na první dokument</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Přepnout na poslední dokument</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Přepnout na dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Nahrávají se nastavení</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Pohotovostní vyrovnávací paměť není zapisovatelná</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nebyl vypnut čistě.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Obnovit z pohotovostní vyrovnávací paměti?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Některé soubory se nepodařilo otevřít.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Některé soubory byly otevřeny pouze pro čtení.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; je novější než kopie ve vyrovnávací paměti.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Přepsat novější soubor?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Uložit změny?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Uložit změny do souboru &apos;%1&apos; před zavřením?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vaše změny budou ztraceny, pokud je neuložíte.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nelze nahrát zvuky psacího stroje.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otevřít...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Nahrát z&amp;novu</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Uložit &amp;jako...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Pře&amp;jmenovat...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>U&amp;ložit vše</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Spravovat sezení</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nové sezení</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tisk...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Nastavení &amp;stránky...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Zn&amp;ovu</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Vyj&amp;mout</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Vložit ne&amp;formátované</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Vybrat &amp;vše</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Vybrat &amp;scénu</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Formát</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Nadpis</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Nadpis &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Nadpis &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Nadpis &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Nadpis &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Nadpis &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Nadpis &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normální</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kurzíva</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Podtržení</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Přeškr&amp;tnutí</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Horní index</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Dolní index</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Zarovnat &amp;vlevo</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Zarovnat na &amp;střed</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Zarovnat vp&amp;ravo</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Zarovnat do &amp;bloku</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Z&amp;menšit odsazení</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Zvětš&amp;it odsazení</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blok zl&amp;eva doprava</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blok z&amp;prava doleva</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Hledat...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Najít &amp;další</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Najít &amp;předchozí</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Nahradit...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Typografické &amp;uvozovky</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Obnovit &amp;dokument</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Obnovit typografické uvozovky dokumentu</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Obnovit &amp;výběr</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Obnovit typografické uvozovky výběru</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Pravopis...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Nastavit &amp;jazyk...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Časo&amp;míry...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboly...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Denní postup</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Ukázat ná&amp;strojový pruh</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Ukázat &amp;nabídkové ikony</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Zao&amp;střený text</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Z&amp;menšit na panel</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Vzhled...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nastavení...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Zaměření vypnuto</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Zaměření na jeden řádek</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Zaměření na tři řádky</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Odstavec</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Zaměření na odstavec</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jazyk &amp;programu...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Některé soubory nebyly podporovány a nepodařilo se je otevřít.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Vypnuto</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Jeden řá&amp;dek</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tři řádky</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
</context>
</TS>
